@@ -2,17 +2,20 @@
 
 # Classes
 from la.deflarry import larry
-del deflarry  # Remove deflarry from namespace
 
 try:
     from la.io import (IO, save, load, repack, is_archived_larry,
                        archive_directory)
-except (ImportError, ValueError):
-    print "Cannot import h5py; no archiving available."        
+except:
+    # Cannot import h5py; no archiving available.
+    pass        
 
 from numpy import nan, inf
 
-from la.func import union, intersection, stack, panel, cov
+from la.flarry import (union, intersection, stack, panel, cov, rand, randn,
+                       align, align_raw, binaryop, add, subtract, multiply,
+                       divide)
+from la.util.report import info                     
 from la.version import __version__
 from la.util import testing
 
@@ -22,3 +25,9 @@ try:
     del Tester
 except (ImportError, ValueError):
     print "No la unit testing available."
+    
+try:
+    # Namespace cleaning
+    del deflarry, flabel, func, io, missing, testing, util, version
+except:
+    pass     
