@@ -1,3 +1,4 @@
+"larry IO module."
 
 import os
 import datetime
@@ -89,10 +90,9 @@ class IO(object):
         
         Examine the contents of the archive:
         
-        >>> io
-           
+        >>> io   
         larry  dtype  shape
-        -------------------
+        ------------------
         x      int64  (3,)
         
         Overwrite the contents of x in the archive: 
@@ -239,6 +239,7 @@ class IO(object):
         global size
         size = 0
         def sizefinder(key, value):
+            "Add size of object to running total"
             global size
             if isinstance(value, h5py.Dataset):
                 size += value.id.get_storage_size()
@@ -257,6 +258,7 @@ class IO(object):
                 
     @property    
     def filename(self):
+        "filename of archive."
         return self.f.filename                
                               
 class lara(object):
@@ -328,13 +330,15 @@ class lara(object):
         
     @property
     def ndim(self):
+        "Number of dimensions."
         return len(self.shape)                       
 
     @property
     def size(self):
+        "Number of elements."
         return np.prod(self.shape, dtype=int)
         
-# Archive functions ---------------------------------------------------------       
+# Archive functions ---------------------------------------------------------
 
 def save(file, lar, key):
     """
@@ -377,7 +381,7 @@ def save(file, lar, key):
     --------
     Create a larry:
     
-    >>> la.save(x, 'x')
+    >>> x = la.larry([1, 2, 3])
 
     Save the larry:
 
@@ -444,7 +448,7 @@ def load(file, key):
     --------
     Create a larry:
     
-    >>> la.save(x, 'x')
+    >>> x = la.larry([1, 2, 3])
 
     Save the larry:
 
@@ -502,7 +506,7 @@ def delete(file, key):
     --------
     Create a larry:
     
-    >>> la.save(x, 'x')
+    >>> x = la.larry([1, 2, 3])
 
     Save the larry:
 
@@ -510,7 +514,7 @@ def delete(file, key):
     
     Now delete it:
     
-    >>> y = la.delete('/tmp/x.hdf5', 'x')            
+    >>> la.delete('/tmp/x.hdf5', 'x')            
  
     """
     
@@ -589,7 +593,7 @@ def archive_directory(file):
         f.close()
     return keys            
     
-# Utility functions for internal use ----------------------------------------                  
+# Utility functions for internal use ----------------------------------------
 
 def _load_label(group, ndim):
     "Load larry labels from archive given the hpy5.Group object of the larry."
