@@ -6,10 +6,10 @@ nan = np.nan
 
 from la.util.testing import printfail
 from la.util.scipy import nanstd
-from la.afunc import (covMissing, push, geometric_mean, lastrank,
-                      movingrank, movingsum, movingsum_forward, nans,
-                      quantile, ranking, group_mean, group_median,
-                      group_ranking, nanmedian)
+from la.farray import (covMissing, push, geometric_mean, lastrank,
+                       movingrank, movingsum, movingsum_forward,
+                       quantile, ranking, group_mean, group_median,
+                       group_ranking, nanmedian)
 
 # Functions to test
 funcs_one = [geometric_mean, lastrank, nanstd, ranking, nanmedian]
